==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/syntex/kotlin/DocumentProcessor.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.syntex.kotlin

import com.pulumi.azurenative.syntex.kotlin.outputs.DocumentProcessorPropertiesResponse
import com.pulumi.azurenative.syntex.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.syntex.kotlin.outputs.DocumentProcessorPropertiesResponse.Companion.toKotlin as documentProcessorPropertiesResponseToKotlin
import com.pulumi.azurenative.syntex.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [DocumentProcessor].
 */
@PulumiTagMarker
public class DocumentProcessorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DocumentProcessorArgs = DocumentProcessorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DocumentProcessorArgsBuilder.() -> Unit) {
        val builder = DocumentProcessorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): DocumentProcessor {
        val builtJavaResource = com.pulumi.azurenative.syntex.DocumentProcessor(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return DocumentProcessor(builtJavaResource)
    }
}

/**
 * Document processor details
 * Azure REST API version: 2022-09-15-preview. Prior API version in Azure Native 1.x: 2022-09-15-preview.
 * ## Example Usage
 * ### DocumentProcessor_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var documentProcessor = new AzureNative.Syntex.DocumentProcessor("documentProcessor", new()
 *     {
 *         Location = "westus",
 *         ProcessorName = "myprocessor",
 *         Properties = new AzureNative.Syntex.Inputs.DocumentProcessorPropertiesArgs
 *         {
 *             SpoTenantId = "e9bb744b-9558-4dc6-9e50-a3297e3332fa",
 *             SpoTenantUrl = "https://test123.sharepoint.com",
 *         },
 *         ResourceGroupName = "mygroup",
 *         Tags =
 *         {
 *             { "additionalProp1", "string1" },
 *             { "additionalProp2", "string2" },
 *             { "additionalProp3", "string3" },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/syntex/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := syntex.NewDocumentProcessor(ctx, "documentProcessor", &syntex.DocumentProcessorArgs{
 * 			Location:      pulumi.String("westus"),
 * 			ProcessorName: pulumi.String("myprocessor"),
 * 			Properties: &syntex.DocumentProcessorPropertiesArgs{
 * 				SpoTenantId:  pulumi.String("e9bb744b-9558-4dc6-9e50-a3297e3332fa"),
 * 				SpoTenantUrl: pulumi.String("https://test123.sharepoint.com"),
 * 			},
 * 			ResourceGroupName: pulumi.String("mygroup"),
 * 			Tags: pulumi.StringMap{
 * 				"additionalProp1": pulumi.String("string1"),
 * 				"additionalProp2": pulumi.String("string2"),
 * 				"additionalProp3": pulumi.String("string3"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.syntex.DocumentProcessor;
 * import com.pulumi.azurenative.syntex.DocumentProcessorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var documentProcessor = new DocumentProcessor("documentProcessor", DocumentProcessorArgs.builder()
 *             .location("westus")
 *             .processorName("myprocessor")
 *             .properties(Map.ofEntries(
 *                 Map.entry("spoTenantId", "e9bb744b-9558-4dc6-9e50-a3297e3332fa"),
 *                 Map.entry("spoTenantUrl", "https://test123.sharepoint.com")
 *             ))
 *             .resourceGroupName("mygroup")
 *             .tags(Map.ofEntries(
 *                 Map.entry("additionalProp1", "string1"),
 *                 Map.entry("additionalProp2", "string2"),
 *                 Map.entry("additionalProp3", "string3")
 *             ))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:syntex:DocumentProcessor myprocessor /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Syntex/documentProcessors/{processorName}
 * ```
 */
public class DocumentProcessor internal constructor(
    override val javaResource: com.pulumi.azurenative.syntex.DocumentProcessor,
) : KotlinCustomResource(javaResource, DocumentProcessorMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Document processor properties.
     */
    public val properties: Output<DocumentProcessorPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                documentProcessorPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DocumentProcessorMapper : ResourceMapper<DocumentProcessor> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.syntex.DocumentProcessor::class == javaResource::class

    override fun map(javaResource: Resource): DocumentProcessor = DocumentProcessor(
        javaResource as
            com.pulumi.azurenative.syntex.DocumentProcessor,
    )
}

/**
 * @see [DocumentProcessor].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DocumentProcessor].
 */
public suspend fun documentProcessor(
    name: String,
    block: suspend DocumentProcessorResourceBuilder.() -> Unit,
): DocumentProcessor {
    val builder = DocumentProcessorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DocumentProcessor].
 * @param name The _unique_ name of the resulting resource.
 */
public fun documentProcessor(name: String): DocumentProcessor {
    val builder = DocumentProcessorResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/syntex/kotlin/DocumentProcessor.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.syntex.kotlin

import com.pulumi.azurenative.syntex.kotlin.outputs.DocumentProcessorPropertiesResponse
import com.pulumi.azurenative.syntex.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import com.pulumi.azurenative.syntex.kotlin.outputs.DocumentProcessorPropertiesResponse.Companion.toKotlin as documentProcessorPropertiesResponseToKotlin
import com.pulumi.azurenative.syntex.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [DocumentProcessor].
 */
@PulumiTagMarker
public class DocumentProcessorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: DocumentProcessorArgs = DocumentProcessorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend DocumentProcessorArgsBuilder.() -> Unit) {
        val builder = DocumentProcessorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): DocumentProcessor {
        val builtJavaResource = com.pulumi.azurenative.syntex.DocumentProcessor(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return DocumentProcessor(builtJavaResource)
    }
}

/**
 * Document processor details
 * Azure REST API version: 2022-09-15-preview. Prior API version in Azure Native 1.x: 2022-09-15-preview.
 * ## Example Usage
 * ### DocumentProcessor_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var documentProcessor = new AzureNative.Syntex.DocumentProcessor("documentProcessor", new()
 *     {
 *         Location = "westus",
 *         ProcessorName = "myprocessor",
 *         Properties = new AzureNative.Syntex.Inputs.DocumentProcessorPropertiesArgs
 *         {
 *             SpoTenantId = "e9bb744b-9558-4dc6-9e50-a3297e3332fa",
 *             SpoTenantUrl = "https://test123.sharepoint.com",
 *         },
 *         ResourceGroupName = "mygroup",
 *         Tags =
 *         {
 *             { "additionalProp1", "string1" },
 *             { "additionalProp2", "string2" },
 *             { "additionalProp3", "string3" },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/syntex/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := syntex.NewDocumentProcessor(ctx, "documentProcessor", &syntex.DocumentProcessorArgs{
 * 			Location:      pulumi.String("westus"),
 * 			ProcessorName: pulumi.String("myprocessor"),
 * 			Properties: &syntex.DocumentProcessorPropertiesArgs{
 * 				SpoTenantId:  pulumi.String("e9bb744b-9558-4dc6-9e50-a3297e3332fa"),
 * 				SpoTenantUrl: pulumi.String("https://test123.sharepoint.com"),
 * 			},
 * 			ResourceGroupName: pulumi.String("mygroup"),
 * 			Tags: pulumi.StringMap{
 * 				"additionalProp1": pulumi.String("string1"),
 * 				"additionalProp2": pulumi.String("string2"),
 * 				"additionalProp3": pulumi.String("string3"),
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.syntex.DocumentProcessor;
 * import com.pulumi.azurenative.syntex.DocumentProcessorArgs;
 * import com.pulumi.azurenative.syntex.inputs.DocumentProcessorPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var documentProcessor = new DocumentProcessor("documentProcessor", DocumentProcessorArgs.builder()
 *             .location("westus")
 *             .processorName("myprocessor")
 *             .properties(DocumentProcessorPropertiesArgs.builder()
 *                 .spoTenantId("e9bb744b-9558-4dc6-9e50-a3297e3332fa")
 *                 .spoTenantUrl("https://test123.sharepoint.com")
 *                 .build())
 *             .resourceGroupName("mygroup")
 *             .tags(Map.ofEntries(
 *                 Map.entry("additionalProp1", "string1"),
 *                 Map.entry("additionalProp2", "string2"),
 *                 Map.entry("additionalProp3", "string3")
 *             ))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:syntex:DocumentProcessor myprocessor /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Syntex/documentProcessors/{processorName}
 * ```
 */
public class DocumentProcessor internal constructor(
    override val javaResource: com.pulumi.azurenative.syntex.DocumentProcessor,
) : KotlinCustomResource(javaResource, DocumentProcessorMapper) {
    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Document processor properties.
     */
    public val properties: Output<DocumentProcessorPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                documentProcessorPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object DocumentProcessorMapper : ResourceMapper<DocumentProcessor> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.syntex.DocumentProcessor::class == javaResource::class

    override fun map(javaResource: Resource): DocumentProcessor = DocumentProcessor(
        javaResource as
            com.pulumi.azurenative.syntex.DocumentProcessor,
    )
}

/**
 * @see [DocumentProcessor].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [DocumentProcessor].
 */
public suspend fun documentProcessor(
    name: String,
    block: suspend DocumentProcessorResourceBuilder.() -> Unit,
): DocumentProcessor {
    val builder = DocumentProcessorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [DocumentProcessor].
 * @param name The _unique_ name of the resulting resource.
 */
public fun documentProcessor(name: String): DocumentProcessor {
    val builder = DocumentProcessorResourceBuilder()
    builder.name(name)
    return builder.build()
}
